==> haskell-http2-3.0.2-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http2
version:              3.0.2
visibility:           public
id:                   http2-3.0.2-Krs9770VjgwLpLcliYNrpk
key:                  http2-3.0.2-Krs9770VjgwLpLcliYNrpk
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http2
synopsis:             HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK, client and server.

category:             Network
abi:                  e088ecbfc667f6324269d4a5aa9d9bd7
exposed:              True
exposed-modules:
    Network.HPACK Network.HPACK.Internal Network.HPACK.Table
    Network.HPACK.Token Network.HTTP2 Network.HTTP2.Client
    Network.HTTP2.Client.Internal Network.HTTP2.Frame
    Network.HTTP2.Internal Network.HTTP2.Priority
    Network.HTTP2.Priority.Internal Network.HTTP2.Server
    Network.HTTP2.Server.Internal

hidden-modules:
    Imports Network.HPACK.Builder Network.HTTP2.Client.Types
    Network.HTTP2.Client.Run Network.HPACK.HeaderBlock
    Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
    Network.HPACK.HeaderBlock.Integer Network.HPACK.Huffman
    Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
    Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
    Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
    Network.HPACK.Huffman.Tree Network.HPACK.Table.Dynamic
    Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
    Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Arch
    Network.HTTP2.Arch.Cache Network.HTTP2.Arch.Config
    Network.HTTP2.Arch.Context Network.HTTP2.Arch.EncodeFrame
    Network.HTTP2.Arch.File Network.HTTP2.Arch.HPACK
    Network.HTTP2.Arch.Manager Network.HTTP2.Arch.Queue
    Network.HTTP2.Arch.Rate Network.HTTP2.Arch.ReadN
    Network.HTTP2.Arch.Receiver Network.HTTP2.Arch.Sender
    Network.HTTP2.Arch.Status Network.HTTP2.Arch.Stream
    Network.HTTP2.Arch.Types Network.HTTP2.Frame.Decode
    Network.HTTP2.Frame.Encode Network.HTTP2.Frame.Types
    Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
    Network.HTTP2.Server.Run Network.HTTP2.Server.Types
    Network.HTTP2.Server.Worker

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http2-3.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http2-3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http2
hs-libraries:         HShttp2-3.0.2-Krs9770VjgwLpLcliYNrpk
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-AqrB7AkGRPa9XAwN5I01IU containers-0.6.4.1
    http-types-0.12.3-6Nz9hNMUgocCYAnwUrPyc
    network-3.1.2.7-1YN9TNDHpA98X2vaYXBgq6
    network-byte-order-0.1.6-JrIwaEYxwdE8gyQmhhYcZz
    psqueues-0.2.7.3-DKOFoiZgHHyDyVIOYV6cPC stm-2.5.0.0
    time-manager-0.0.0-8vLwyp4vzZOJtzkNUtJ8HI
    unix-time-0.4.7-17BeHDgwVCQJaHRaUO9LF8

haddock-interfaces:   /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html:         /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-3.0.2-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http2
version:              3.0.2
visibility:           public
id:                   http2-3.0.2-43tNHDYbKlB36J9kdSkLld
key:                  http2-3.0.2-43tNHDYbKlB36J9kdSkLld
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http2
synopsis:             HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK, client and server.

category:             Network
abi:                  75519ef1858920d10da85a1da68fa227
exposed:              True
exposed-modules:
    Network.HPACK Network.HPACK.Internal Network.HPACK.Table
    Network.HPACK.Token Network.HTTP2 Network.HTTP2.Client
    Network.HTTP2.Client.Internal Network.HTTP2.Frame
    Network.HTTP2.Internal Network.HTTP2.Priority
    Network.HTTP2.Priority.Internal Network.HTTP2.Server
    Network.HTTP2.Server.Internal

hidden-modules:
    Imports Network.HPACK.Builder Network.HTTP2.Client.Types
    Network.HTTP2.Client.Run Network.HPACK.HeaderBlock
    Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
    Network.HPACK.HeaderBlock.Integer Network.HPACK.Huffman
    Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
    Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
    Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
    Network.HPACK.Huffman.Tree Network.HPACK.Table.Dynamic
    Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
    Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Arch
    Network.HTTP2.Arch.Cache Network.HTTP2.Arch.Config
    Network.HTTP2.Arch.Context Network.HTTP2.Arch.EncodeFrame
    Network.HTTP2.Arch.File Network.HTTP2.Arch.HPACK
    Network.HTTP2.Arch.Manager Network.HTTP2.Arch.Queue
    Network.HTTP2.Arch.Rate Network.HTTP2.Arch.ReadN
    Network.HTTP2.Arch.Receiver Network.HTTP2.Arch.Sender
    Network.HTTP2.Arch.Status Network.HTTP2.Arch.Stream
    Network.HTTP2.Arch.Types Network.HTTP2.Frame.Decode
    Network.HTTP2.Frame.Encode Network.HTTP2.Frame.Types
    Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
    Network.HTTP2.Server.Run Network.HTTP2.Server.Types
    Network.HTTP2.Server.Worker

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http2-3.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http2-3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http2
hs-libraries:         HShttp2-3.0.2-43tNHDYbKlB36J9kdSkLld
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-LFqu6hRGbna4Vnd1Zm6Vxy containers-0.6.4.1
    http-types-0.12.3-HpvMf1FhGSo5yZ9uunhMJt
    network-3.1.2.7-3dAlKyu2TU91rkKNmDqxd9
    network-byte-order-0.1.6-AO638RXVGiI3RG9PmwKq0f
    psqueues-0.2.7.3-IBXV1aH48iW23Dj7YJDd5p stm-2.5.0.0
    time-manager-0.0.0-1j6cp6bnIG34mQFYlvAHES
    unix-time-0.4.7-6F9tYT04a36JaKJmBYdAsX

haddock-interfaces:   /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html:         /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
